OC.L10N.register(
    "activity",
    {
    "Activity" : "動態",
    "An error occurred while loading activities" : "載入動態時出錯",
    "No activity yet" : "暫無動態",
    "Load more activities" : "載入更多動態",
    "Copied!" : "已複製!",
    "Not supported!" : "不支援!",
    "Press ⌘-C to copy." : "按下 ⌘-C 複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 複製",
    "{name} (invisible)" : "{name} (不可見)",
    "{name} (restricted)" : "{name} (受限的)",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "stream中會顯示諸如添加、更改和分享之類的事件",
    "There are no events for this filter" : "沒有符合當前篩選條件的事件。",
    "Today" : "今日",
    "Yesterday" : "明日",
    "Open file" : "開啟檔案",
    "Personal activity feed for %s" : "%s 的個人動態 Feed",
    "Your feed URL is invalid" : "您輸入的Feed鏈接無效",
    "Your settings have been updated." : "您的設置已更新。",
    "Settings have been updated." : "設置已更新。",
    "All activities" : "所有動態",
    "By others" : "其他來源",
    "By you" : "本地来源",
    "Hello %s" : "你好%s",
    "Hello %s," : "你好%s",
    "There was some activity at %s" : "在%s 裡有一些動態",
    "_and %n more _::_and %n more _" : ["和%n等"],
    "Mail" : "郵件",
    "Stream" : "Stream",
    "Activity feed" : "動態  feed",
    "Default settings" : "預設設定",
    "Configure the default activity settings for new users." : "為新用戶設置默認的活動配置",
    "List your own actions in the stream" : "在stream裡面列出您自己的行為",
    "Notify about your own actions via email" : "通過郵件通知您自己的動態",
    "You need to set up your email address before you can receive notification emails." : "要接收通知郵件，需要先設置您的電子郵件地址。",
    "Send emails:" : "發送郵件：",
    "As soon as possible" : "盡快",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每星期",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "選擇哪些活動你想收到提示郵件，這將顯示在活動應用stream裡",
    "Settings" : "設定",
    "Enable RSS feed" : "啟用 RSS 源",
    "No more events to load" : "已無更多事件",
    "\"remote user\"" : "遠程用戶",
    ", " : ",",
    "%s and %s" : "%s和%s",
    "Files" : "檔案"
},
"nplurals=1; plural=0;");
